@@ -1,5 +1,6 @@
 # Standard library
 from typing import (
+    List,
     NamedTuple,
 )
 
@@ -10,6 +11,12 @@ Frame = NamedTuple('Frame', [
     ('signature', str),
     ('timestamp', float),
 ])
+
+DaemonResult = NamedTuple('DaemonResult', [
+    ('stack', List[Frame]),
+    ('stdout', str),
+])
+
 LoopSnapshot = NamedTuple('LoopSnapshot', [
     ('block_duration_ratio', float),
     ('wanted_tick_duration', float),
